Tutorial — gensim documentation

### Navigation

- index
- modules |
- next |
- previous |
- gensim documentation »

# Tutorial

This tutorial is organized as a series of examples that highlight various features of gensim. It is assumed that the reader is familiar with the Python language and has read the Introduction.

All the examples can be directly copied to your Python interpreter shell (assuming you have gensim installed, of course). IPython‘s `cpaste` command is especially handy for copypasting code fragments which include superfluous characters, such as the leading `>>>`.

Gensim uses Python’s standard `logging` module to log various stuff at various priority levels; to activate logging (optional), run

    >>> import logging
    >>> logging.root.level = logging.INFO # will suppress DEBUG level events

The examples are divided into parts on:

- Corpora and Vector Spaces
  - Quick Example
  - From Strings to Vectors
  - Corpus Formats
- Topics and Transformations
- Similarity Queries

### Navigation

- index
- modules |
- next |
- previous |
- gensim documentation »